use std::sync::Arc;

use octopush_core::{
    git::{github::GitHubGitProvider, DynGitProvider},
    storage::{local::LocalStorageEngine, DynStorageEngine},
};

pub struct ServiceRegister {
    pub storage_engine: DynStorageEngine,
    pub git_provider: DynGitProvider,
}

impl ServiceRegister {
    pub fn new() -> Self {
        let storage_engine = Arc::new(LocalStorageEngine::new("/tmp/octopush".into()));
        let git_provider = Arc::new(GitHubGitProvider::new(storage_engine.clone()));

        Self {
            storage_engine,
            git_provider,
        }
    }

    pub async fn cleanup(self) -> eyre::Result<()> {
        self.storage_engine.cleanup().await
    }
}
